@@ -11,11 +11,11 @@ This plugin is designed to automatically accept comments which have been
 submitted from known-good IP addresses.
 
 This plugin allows the XML-RPC connection which arrived to contain the
-whitelisted IP addresses and also will compare IP addresses to a server-wide
-whitelist file.
+whitelisted IP addresses - it doesn't whitelist addresses which are
+recorded upon the server this code is running upon.
 
-B<Note>: The server administrator is responsible for populating the
-global whitelist file (/etc/blogspam/goodips).
+There is also a locally tested file which is consulted for a list of
+IP addresses, which is /etc/blogspam/goodips.
 
 =cut
 
@@ -23,27 +23,28 @@ global whitelist file (/etc/blogspam/goodips).
 
 When an incoming comment is submitted for SPAM detection a number of
 optional parameters may be included.  One of the optional parameters
-is a list of CIDR ranges to automatically whitelist, which will always
-receive an "OK" result from.
+is a list of CIDR ranges to automatically blacklist, and always return
+a "SPAM" result from.
 
-The options are discussed as part of the L<Blog::Spam::API>, in the
-section L<TESTING OPTIONS|Blog::Spam::API/"TESTING OPTIONS">.
+For full details of the available options please consult http://api.blogspam.net/
+
+=cut
+
+=head1 LICENSE
+
+This code is licensed under the terms of the GNU General Public
+License, version 2.  See included file GPL-2 for details.
 
 =cut
 
 =head1 AUTHOR
 
-=over 4
-
-=item Steve Kemp
-
+Steve
+--
 http://www.steve.org.uk/
 
-=back
-
 =cut
 
-
 =head1 LICENSE
 
 Copyright (c) 2008-2010 by Steve Kemp.  All rights reserved.
@@ -66,6 +67,8 @@ use Net::CIDR::Lite;
 
 Constructor.  Called when this plugin is instantiated.
 
+This merely saves away the name of our plugin.
+
 =end doc
 
 =cut
@@ -76,10 +79,14 @@ sub new
     my $class = ref($proto) || $proto;
 
     my $self = {};
+    $self->{ 'name' } = $proto;
 
-    # whitelist file.
+    # blacklist file.
     $self->{ 'whitelist-file' } = "/etc/blogspam/goodips";
 
+    # blacklist dir.
+    $self->{ 'whitelist-dir' } = "/etc/whitelist.d/";
+
     # verbose?
     $self->{ 'verbose' } = $supplied{ 'verbose' } || 0;
 
@@ -88,6 +95,13 @@ sub new
 }
 
 
+sub name
+{
+    my ($self) = (@_);
+    return ( $self->{ 'name' } );
+}
+
+
 
 =begin doc
 
@@ -132,7 +146,7 @@ sub testComment
     #
     #  Now look for a local whitelist file.
     #
-    my $file = $self->{ 'whitelist-file' } || undef;
+    my $file = $self->{ 'blacklist-file' } || undef;
 
     #
     #  If there is no list then we cannot block.
@@ -156,7 +170,7 @@ sub testComment
         $self->{ 'gips' } = undef;
 
         $self->{ 'verbose' } &&
-          print "re-reading whitelist file $file\n";
+          print $self->name() . ": re-reading whitelist file $file\n";
 
         if ( open( IPS, "<", $file ) )
         {
